Datatypes – fiscaliza
Description: Classes para modelar as diferentes estruturas de dados a serem enviadas para o Redmine

# Datatypes

Classes para modelar as diferentes estruturas de dados a serem enviadas para o Redmine

### AtomicField

>      AtomicField (name:str, keyword:str, mandatory:bool=True)

### SimpleField

>      SimpleField (id:int, name:str, mandatory:bool=False, multiple:bool=False,
>                   format_value:bool=False, _dtype:str='string')

### EncodedString

>      EncodedString (id:int, name:str, mandatory:bool=False,
>                     multiple:bool=False, format_value:bool=False,
>                     _dtype:str='string')

This class always format the value string The json key is called ‘numero’

### FieldWithOptions

>      FieldWithOptions (id:int, name:str, mandatory:bool=False,
>                        multiple:bool=False, format_value:bool=False,
>                        _dtype:str='string', options:list[str]=None,
>                        mapping:dict[str,list]=None)

### Coordenadas

>      Coordenadas (id:int, name:str, mandatory:bool=False)

### GerarPlai

>      GerarPlai (id:int, name:str, mandatory:bool=False)